import { __decorate, __param, __metadata } from 'tslib';
import { InjectionToken, Injectable, Optional, Inject, defineInjectable, inject, Component, NgModule, NgZone, EventEmitter, Input, Output, Directive, ElementRef } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';

class WindowRef {
    getNativeWindow() { return window; }
}
// tslint:disable-next-line:max-classes-per-file
class DocumentRef {
    getNativeDocument() {
        return document;
    }
}
const BROWSER_GLOBALS_PROVIDERS = [WindowRef, DocumentRef];

/**
 * Token for the config of the YaMapsAPILoaderConfigLiteral. Please provide an object of type {@link
  * YaMapsAPILoaderConfigLiteral}.
  */
const LAZY_MAPS_API_CONFIG = new InjectionToken('angular-ya-maps MAPS_API_CONFIG');
let YaMapsAPILoader = class YaMapsAPILoader {
    constructor(config = null, w, d) {
        this.config = config;
        this._windowRef = w;
        this._documentRef = d;
    }
    load() {
        const script = this._documentRef.getNativeDocument().createElement('script');
        script.type = 'text/javascript';
        script.async = false;
        script.defer = true;
        script.id = 'YaScript';
        script.src = `https://api-maps.yandex.ru/2.1.73/?apikey=${this.config.apiKey}&lang=ru_RU`;
        // tslint:disable-next-line:ban-types
        this._scriptLoadingPromise = new Promise((resolve, reject) => {
            script.onload = () => { resolve(); };
            script.onerror = (error) => { reject(); };
        });
        this._documentRef.getNativeDocument().body.appendChild(script);
        return this._scriptLoadingPromise;
    }
};
YaMapsAPILoader = __decorate([
    Injectable(),
    __param(0, Optional()), __param(0, Inject(LAZY_MAPS_API_CONFIG)),
    __metadata("design:paramtypes", [Object, WindowRef, DocumentRef])
], YaMapsAPILoader);

let YamapngService = class YamapngService {
    constructor(config = null, http) {
        this.http = http;
        this.config = config;
        this.url = `https://geocode-maps.yandex.ru/1.x/?apikey=${this.config.apiKey}&format=json&`;
    }
    getAddressFromCoords(lat, lng) {
        return this.http.get(this.url + 'geocode=' + lng + `,` + lat);
    }
    getCoordsFromAddress(adress) {
        return this.http.get(this.url + 'geocode=' + adress);
    }
    createSuggest(el, opt) {
        this.suggestView = new ymaps.SuggestView(el, opt);
        return this.suggestView;
    }
    parseAutoComplite() {
        const arrStr = this.suggestView.state.get('items');
        arrStr.forEach(element => {
            console.log(element);
            element.displayName = element.displayName + '123';
        });
        this.suggestView.state.set('items', arrStr);
    }
    getSuggests(request, opt) {
        return ymaps.suggest(request, opt);
    }
};
YamapngService.ngInjectableDef = defineInjectable({ factory: function YamapngService_Factory() { return new YamapngService(inject(LAZY_MAPS_API_CONFIG, 8), inject(HttpClient)); }, token: YamapngService, providedIn: "root" });
YamapngService = __decorate([
    Injectable({
        providedIn: 'root',
    }),
    __param(0, Optional()), __param(0, Inject(LAZY_MAPS_API_CONFIG)),
    __metadata("design:paramtypes", [Object, HttpClient])
], YamapngService);

let YamapngComponent = class YamapngComponent {
    constructor() { }
    ngOnInit() {
    }
};
YamapngComponent = __decorate([
    Component({
        selector: 'lib-yamapng',
        template: `
    <p>
      yamapng works!
    </p>
  `
    }),
    __metadata("design:paramtypes", [])
], YamapngComponent);

let YamapngModule = class YamapngModule {
};
YamapngModule = __decorate([
    NgModule({
        declarations: [YamapngComponent],
        imports: [],
        exports: [YamapngComponent]
    })
], YamapngModule);

let YaMapsAPIWrapper = class YaMapsAPIWrapper {
    constructor(_loader, _zone, d) {
        this._loader = _loader;
        this._zone = _zone;
        this._documentRef = d;
        this._map = new Promise((resolve) => {
            this._mapResolver = resolve;
        });
    }
    createMap(el, mapOptions) {
        const res = this._loader.load().then(() => {
            const create = () => setTimeout(() => {
                if (ymaps.Map) {
                    const map = new ymaps.Map(el, mapOptions, {
                        suppressMapOpenBlock: true
                    });
                    this._mapResolver(map);
                }
                else {
                    create();
                }
            }, 100);
            create();
        }).catch((e) => console.log(e));
        return res;
    }
    destroyMap() {
        this._map.then((map) => {
            map.destroy();
        });
    }
    setCenter(latitude, longitude) {
        this._map.then((map) => {
            map.setCenter([latitude, longitude]);
        });
    }
    getCenter() {
        return this._map.then((map) => {
            return map.getCenter();
        });
    }
    panTo(points, options) {
        this._map.then((map) => {
            map.panTo(points, options);
        });
    }
    subscribeToMapEvent(eventName) {
        return Observable.create((observer) => {
            this._map.then((m) => {
                m.events.add(eventName, (arg) => { this._zone.run(() => observer.next(arg)); });
            });
        });
    }
    createMarker(marker) {
        return this._map.then((map) => {
            const m = new ymaps.Placemark([marker.latitude, marker.longitude], {
                balloonContentHeader: marker.balloonContentHeader,
                balloonContentBody: marker.balloonContentBody,
                balloonContentFooter: marker.balloonContentFooter,
                iconContent: marker.iconContent
            }, {
                draggable: marker.draggable,
                preset: marker.preset,
                iconLayout: marker.iconLayout,
                iconImageHref: marker.iconImageHref,
                iconImageSize: marker.iconImageSize,
                iconImageOffset: marker.iconImageOffset
            });
            map.geoObjects.add(m);
            return m;
        });
    }
    removeGeo(overlay) {
        this._map.then((map) => {
            map.geoObjects.remove(overlay);
        });
    }
    createClaster(claster) {
        return this._map.then((map) => {
            if (claster.markers.length === 0) {
                return;
            }
            let myGeoObjects;
            myGeoObjects = new Array();
            claster.markers.forEach((x) => {
                const point = new ymaps.GeoObject({
                    geometry: { type: x.type, coordinates: [x.lat, x.lng] }
                });
                myGeoObjects.push(point);
            });
            const clusterer = new ymaps.Clusterer({});
            clusterer.add(myGeoObjects);
            map.geoObjects.add(clusterer);
            return clusterer;
        });
    }
    createObjectManager(objectManager) {
        return this._map.then((map) => {
            if (objectManager.datasource.length === 0) {
                return;
            }
            const nativeObjectManager = new ymaps.ObjectManager({
                clusterize: objectManager.clusterize,
                gridSize: objectManager.gridSize
            });
            nativeObjectManager.add(objectManager.datasource);
            nativeObjectManager.objects.options.set('preset', objectManager.objectPreset);
            nativeObjectManager.clusters.options.set('preset', objectManager.clasterPreset);
            map.geoObjects.add(nativeObjectManager);
            return nativeObjectManager;
        });
    }
    navigateToGeoObject(objectManager, id) {
        const obj = objectManager.objects.getById(id);
        if (obj) {
            this.setCenter(obj.geometry.coordinates[0], obj.geometry.coordinates[1]);
            objectManager.objects.balloon.open(id);
        }
    }
    checkYaSciptLoaded() {
        return this._documentRef.getNativeDocument().getElementById('YaScript');
    }
    objectManagerSetFilter(objectManager, filter) {
        objectManager.setFilter(filter);
    }
    addCrosshair() {
        return this._map.then((map) => {
            const style = map.panes.get('events').getElement().style;
            style.background = 'url("http://t1.rbxcdn.com/03e863d541704e442033d597945ab2e6") no-repeat center';
            style.backgroundSize = '100px';
        });
    }
};
YaMapsAPIWrapper = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [YaMapsAPILoader, NgZone, DocumentRef])
], YaMapsAPIWrapper);

let MarkerManager = class MarkerManager {
    constructor(_mapsWrapper, _zone) {
        this._mapsWrapper = _mapsWrapper;
        this._zone = _zone;
        this._markers = new Map();
    }
    deleteMarker(marker) {
        const m = this._markers.get(marker);
        if (m == null) {
            return Promise.resolve();
        }
        // tslint:disable-next-line:no-shadowed-variable
        return m.then((m) => {
            return this._zone.run(() => {
                // tslint:disable-next-line:no-shadowed-variable
                this.getNativeMarker(marker).then((m) => {
                    this._mapsWrapper.removeGeo(m);
                    this._markers.delete(marker);
                });
            });
        });
    }
    addMarker(marker) {
        const markerPromise = this._mapsWrapper.createMarker(marker);
        this._markers.set(marker, markerPromise);
    }
    showBalloon(marker) {
        this.getNativeMarker(marker).then((m) => {
            m.balloon.open();
        });
    }
    getNativeMarker(marker) {
        return this._markers.get(marker);
    }
    createEventObservable(eventName, marker) {
        return Observable.create((observer) => {
            this._markers.get(marker).then((m) => {
                m.events.add(eventName, (e) => this._zone.run(() => observer.next(e)));
            });
        });
    }
};
MarkerManager = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [YaMapsAPIWrapper, NgZone])
], MarkerManager);

let markerId = 0;
let YaMarker = 
// tslint:disable-next-line:directive-class-suffix
class YaMarker {
    constructor(_markerManager) {
        this._markerManager = _markerManager;
        this.draggable = false;
        this.preset = 'islands#blueIcon';
        this.markerClick = new EventEmitter();
        // tslint:disable-next-line:max-line-length
        this.dragEnd = new EventEmitter();
        this._markerAddedToManger = false;
        this._observableSubscriptions = [];
        this._id = (markerId++).toString();
    }
    ngOnChanges(changes) {
        if (!this._markerAddedToManger) {
            this._markerManager.addMarker(this);
            this._markerAddedToManger = true;
            this._addEventListeners();
            return;
        }
        if (changes['showInfo']) {
            this._markerManager.showBalloon(this);
        }
        if (changes['latitude'] || changes['longitude']) {
            this._markerManager.getNativeMarker(this).then((m) => {
                let lt;
                let lg;
                const coords = m.geometry.getCoordinates();
                if (changes['latitude']) {
                    lt = changes['latitude'].currentValue;
                }
                else {
                    lt = coords[0];
                }
                if (changes['longitude']) {
                    lg = changes['longitude'].currentValue;
                }
                else {
                    lg = coords[1];
                }
                m.geometry.setCoordinates([lt, lg]);
            });
        }
    }
    ngOnDestroy() {
        this._markerManager.deleteMarker(this);
        this._observableSubscriptions.forEach((s) => s.unsubscribe());
    }
    _addEventListeners() {
        // click event
        const cs = this._markerManager.createEventObservable('click', this).subscribe(() => {
            this._markerManager.showBalloon(this);
            this.markerClick.emit(null);
        });
        this._observableSubscriptions.push(cs);
        // dragend event
        // tslint:disable-next-line:max-line-length
        const ds = this._markerManager.createEventObservable('dragend', this).subscribe((e) => {
            const thisPlacemark = e.get('target');
            const coords = thisPlacemark.geometry.getCoordinates();
            this._markerManager.getNativeMarker(this).then((m) => {
                // tslint:disable-next-line:max-line-length
                this.dragEnd.emit({ lat: coords[0], lng: coords[1], nativeMarker: m });
            });
        });
        this._observableSubscriptions.push(ds);
    }
};
__decorate([
    Input(),
    __metadata("design:type", Number)
], YaMarker.prototype, "latitude", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], YaMarker.prototype, "longitude", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "balloonLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], YaMarker.prototype, "balloonContentHeader", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], YaMarker.prototype, "balloonContentBody", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], YaMarker.prototype, "balloonContentFooter", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "draggable", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "preset", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], YaMarker.prototype, "iconContent", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], YaMarker.prototype, "showInfo", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "iconLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "iconImageHref", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "iconImageSize", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMarker.prototype, "iconImageOffset", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], YaMarker.prototype, "markerClick", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], YaMarker.prototype, "dragEnd", void 0);
YaMarker = __decorate([
    Directive({
        // tslint:disable-next-line:directive-selector
        selector: 'ya-marker',
        providers: [
            YaMapsAPIWrapper
        ]
    })
    // tslint:disable-next-line:directive-class-suffix
    ,
    __metadata("design:paramtypes", [MarkerManager])
], YaMarker);

let ClasterManager = class ClasterManager {
    constructor(_mapsWrapper, _zone) {
        this._mapsWrapper = _mapsWrapper;
        this._zone = _zone;
        this._clasters = new Map();
    }
    addClaster(claster) {
        const clasterPromise = this._mapsWrapper.createClaster(claster);
        this._clasters.set(claster, clasterPromise);
    }
};
ClasterManager = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [YaMapsAPIWrapper, NgZone])
], ClasterManager);

let clasterId = 0;
let YaClaster = 
// tslint:disable-next-line:directive-class-suffix
class YaClaster {
    constructor(_clasterManager) {
        this._clasterManager = _clasterManager;
        this._markerAddedToManger = false;
        this._id = (clasterId++).toString();
    }
    ngOnChanges(changes) {
        if (!this._markerAddedToManger) {
            this._clasterManager.addClaster(this);
        }
    }
    ngOnDestroy() { }
    _addEventListeners() { }
};
__decorate([
    Input(),
    __metadata("design:type", Array)
], YaClaster.prototype, "markers", void 0);
YaClaster = __decorate([
    Directive({
        // tslint:disable-next-line:directive-selector
        selector: 'ya-claster',
        providers: [
            YaMapsAPIWrapper
        ]
    })
    // tslint:disable-next-line:directive-class-suffix
    ,
    __metadata("design:paramtypes", [ClasterManager])
], YaClaster);

let ObjectManagerManager = class ObjectManagerManager {
    constructor(_mapsWrapper, _zone) {
        this._mapsWrapper = _mapsWrapper;
        this._zone = _zone;
        this._managers = new Map();
    }
    add(manager) {
        const managerPromise = this._mapsWrapper.createObjectManager(manager);
        this._managers.set(manager, managerPromise);
    }
    navigateToGeoObject(manager, id) {
        this.getNativeManager(manager).then((p) => {
            this._mapsWrapper.navigateToGeoObject(p, id);
        });
    }
    getNativeManager(manager) {
        return this._managers.get(manager);
    }
    setFilter(manager, filter) {
        this.getNativeManager(manager).then((p) => {
            this._mapsWrapper.objectManagerSetFilter(p, filter);
        });
    }
};
ObjectManagerManager = __decorate([
    Injectable(),
    __metadata("design:paramtypes", [YaMapsAPIWrapper, NgZone])
], ObjectManagerManager);

let markerId$1 = 0;
let YaObjectManager = 
// tslint:disable-next-line:directive-class-suffix
class YaObjectManager {
    constructor(_manager) {
        this._manager = _manager;
        this.clusterize = false;
        this.clasterPreset = 'islands#blueIcon';
        this.objectPreset = 'islands#blueClusterIcons';
        this.gridSize = 0;
        this._observableSubscriptions = [];
        this._addedToManger = false;
        this._id = (markerId$1++).toString();
    }
    ngOnChanges(changes) {
        if (!this._addedToManger) {
            this._manager.add(this);
            this._addedToManger = true;
            return;
        }
        if (changes['selectedObjectId']) {
            this._manager.navigateToGeoObject(this, this.selectedObjectId);
        }
        if (changes['filter']) {
            this._manager.setFilter(this, this.filter);
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaObjectManager.prototype, "clusterize", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaObjectManager.prototype, "datasource", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaObjectManager.prototype, "clasterPreset", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaObjectManager.prototype, "objectPreset", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaObjectManager.prototype, "gridSize", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], YaObjectManager.prototype, "selectedObjectId", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaObjectManager.prototype, "filter", void 0);
YaObjectManager = __decorate([
    Directive({
        // tslint:disable-next-line:directive-selector
        selector: 'ya-object-manager',
        providers: [
            YaMapsAPIWrapper
        ]
    })
    // tslint:disable-next-line:directive-class-suffix
    ,
    __metadata("design:paramtypes", [ObjectManagerManager])
], YaObjectManager);

let yandex;

let YaMap = 
// class="map-container-inner" id="map"
// tslint:disable-next-line:component-class-suffix
class YaMap {
    constructor(_elem, _mapsWrapper) {
        this._elem = _elem;
        this._mapsWrapper = _mapsWrapper;
        this.longitude = 0;
        this.latitude = 0;
        this.zoom = 8;
        this.mapType = 'yandex#map';
        this.controls = null;
        // tslint:disable-next-line:max-line-length
        this.mapClick = new EventEmitter();
        this.actionTick = new EventEmitter();
        this.boundschange = new EventEmitter();
        this.mapInit = false;
        this._observableSubscriptions = [];
    }
    ngOnInit() {
        console.log('map iit');
        const container = this._elem.nativeElement.querySelector('.map-container-inner');
        this._initMapInstance(container);
        this.mapInit = true;
    }
    ngOnDestroy() {
        console.log('map del');
        this._mapsWrapper.destroyMap();
    }
    ngOnChanges(changes) {
        if (this.mapInit) {
            this.updatePosition(changes);
            this.panTo(changes);
        }
    }
    _initMapInstance(el) {
        if (this.controls != null) {
            this._mapsWrapper.createMap(el, {
                center: [this.latitude, this.longitude], zoom: this.zoom, type: this.mapType,
                controls: this.controls
            });
        }
        else {
            this._mapsWrapper.createMap(el, {
                center: [this.latitude, this.longitude], zoom: this.zoom, type: this.mapType
            });
        }
        if (this.crosshair) {
            this._mapsWrapper.addCrosshair();
        }
        this._handleMapMouseEvents();
    }
    updatePosition(changes) {
        if (changes['latitude'] == null && changes['longitude'] == null) {
            return;
        }
        this._mapsWrapper.setCenter(this.latitude, this.longitude);
    }
    panTo(changes) {
        if (changes['panToObjects'] == null) {
            return;
        }
        this._mapsWrapper.panTo(this.panToObjects.points, this.panToObjects.params);
    }
    _handleMapMouseEvents() {
        const clickEvents = [
            { name: 'click', emitter: this.mapClick }
        ];
        const events = [
            { name: 'actiontick', emitter: this.actionTick }
        ];
        const boundschanges = [
            { name: 'boundschange', emitter: this.boundschange }
        ];
        boundschanges.forEach((e) => {
            const s = this._mapsWrapper.subscribeToMapEvent(e.name).subscribe((event) => {
                this._mapsWrapper.getCenter().then((coords) => {
                    const value = { lat: coords[0], lng: coords[1] };
                    e.emitter.emit(value);
                });
            });
            this._observableSubscriptions.push(s);
        });
        clickEvents.forEach((e) => {
            const s = this._mapsWrapper.subscribeToMapEvent(e.name).subscribe((event) => {
                const coords = event.get('coords');
                const value = { lat: coords[0], lng: coords[1] };
                e.emitter.emit(value);
            });
            this._observableSubscriptions.push(s);
        });
        events.forEach((e) => {
            const s = this._mapsWrapper.subscribeToMapEvent(e.name).subscribe((event) => {
                this._mapsWrapper.getCenter().then((coords) => {
                    this.latitude = coords[0];
                    this.longitude = coords[1];
                    const value = { lat: coords[0], lng: coords[1] };
                    e.emitter.emit(value);
                });
            });
            this._observableSubscriptions.push(s);
        });
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMap.prototype, "longitude", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMap.prototype, "latitude", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMap.prototype, "zoom", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], YaMap.prototype, "minZoom", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], YaMap.prototype, "maxZoom", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMap.prototype, "mapType", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], YaMap.prototype, "controls", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], YaMap.prototype, "panToObjects", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], YaMap.prototype, "crosshair", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], YaMap.prototype, "mapClick", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], YaMap.prototype, "actionTick", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], YaMap.prototype, "boundschange", void 0);
YaMap = __decorate([
    Component({
        // tslint:disable-next-line:component-selector
        selector: 'ya-map',
        providers: [
            YaMapsAPIWrapper,
            MarkerManager,
            ClasterManager,
            ObjectManagerManager
        ],
        template: `
    <div class="map-container-inner" id="map">
      <ng-content></ng-content>
    </div>
  `
    })
    // class="map-container-inner" id="map"
    // tslint:disable-next-line:component-class-suffix
    ,
    __metadata("design:paramtypes", [ElementRef, YaMapsAPIWrapper])
], YaMap);

var YaCoreModule_1;
/**
 * @internal
 */
function coreDirectives() {
    return [
        YaMap,
        YaMarker,
        YaClaster,
        YaObjectManager
    ];
}
/**
 * The angular-ya-maps core module. Contains all Directives/Services/Pipes
 * of the core module. Please use `YaCoreModule.forRoot()` in your app module.
 */
let YaCoreModule = YaCoreModule_1 = class YaCoreModule {
    /**
     * Please use this method when you register the module at the root level.
     */
    static forRoot(yaMapsAPILoaderConfig) {
        return {
            ngModule: YaCoreModule_1,
            providers: [
                ...BROWSER_GLOBALS_PROVIDERS,
                { provide: YaMapsAPILoader, useClass: YaMapsAPILoader },
                { provide: LAZY_MAPS_API_CONFIG, useValue: yaMapsAPILoaderConfig }
            ],
        };
    }
};
YaCoreModule = YaCoreModule_1 = __decorate([
    NgModule({ declarations: coreDirectives(), exports: coreDirectives() })
], YaCoreModule);
function YaCoreModuleForRoot(yaMapsAPILoaderConfig) {
    return [
        YaCoreModule.forRoot(yaMapsAPILoaderConfig)
    ];
}

/*
 * Public API Surface of yamapng
 */

/**
 * Generated bundle index. Do not edit.
 */

export { YaCoreModule, YaCoreModuleForRoot, YamapngComponent, YamapngModule, YamapngService, coreDirectives, yandex, LAZY_MAPS_API_CONFIG as ɵa, YaMapsAPILoader as ɵb, YaMap as ɵc, YaMapsAPIWrapper as ɵd, WindowRef as ɵe, DocumentRef as ɵf, BROWSER_GLOBALS_PROVIDERS as ɵg, MarkerManager as ɵh, ClasterManager as ɵi, ObjectManagerManager as ɵj, YaMarker as ɵk, YaClaster as ɵl, YaObjectManager as ɵm };
//# sourceMappingURL=ayamap.js.map
