import { __decorate, __param, __metadata, __spread } from 'tslib';
import { InjectionToken, Injectable, Optional, Inject, defineInjectable, inject, Component, NgModule, NgZone, Input, Output, EventEmitter, Directive, ElementRef } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable } from 'rxjs';

var WindowRef = /** @class */ (function () {
    function WindowRef() {
    }
    WindowRef.prototype.getNativeWindow = function () { return window; };
    return WindowRef;
}());
// tslint:disable-next-line:max-classes-per-file
var DocumentRef = /** @class */ (function () {
    function DocumentRef() {
    }
    DocumentRef.prototype.getNativeDocument = function () {
        return document;
    };
    return DocumentRef;
}());
var BROWSER_GLOBALS_PROVIDERS = [WindowRef, DocumentRef];

/**
 * Token for the config of the YaMapsAPILoaderConfigLiteral. Please provide an object of type {@link
  * YaMapsAPILoaderConfigLiteral}.
  */
var LAZY_MAPS_API_CONFIG = new InjectionToken('angular-ya-maps MAPS_API_CONFIG');
var YaMapsAPILoader = /** @class */ (function () {
    function YaMapsAPILoader(config, w, d) {
        if (config === void 0) { config = null; }
        this.config = config;
        this._windowRef = w;
        this._documentRef = d;
    }
    YaMapsAPILoader.prototype.load = function () {
        var script = this._documentRef.getNativeDocument().createElement('script');
        script.type = 'text/javascript';
        script.async = false;
        script.defer = true;
        script.id = 'YaScript';
        script.src = "https://api-maps.yandex.ru/2.1.73/?apikey=" + this.config.apiKey + "&lang=ru_RU";
        // tslint:disable-next-line:ban-types
        this._scriptLoadingPromise = new Promise(function (resolve, reject) {
            script.onload = function () { resolve(); };
            script.onerror = function (error) { reject(); };
        });
        this._documentRef.getNativeDocument().body.appendChild(script);
        return this._scriptLoadingPromise;
    };
    YaMapsAPILoader = __decorate([
        Injectable(),
        __param(0, Optional()), __param(0, Inject(LAZY_MAPS_API_CONFIG)),
        __metadata("design:paramtypes", [Object, WindowRef, DocumentRef])
    ], YaMapsAPILoader);
    return YaMapsAPILoader;
}());

var YamapngService = /** @class */ (function () {
    function YamapngService(config, http) {
        if (config === void 0) { config = null; }
        this.http = http;
        this.config = config;
        this.url = "https://geocode-maps.yandex.ru/1.x/?apikey=" + this.config.apiKey + "&format=json&";
    }
    YamapngService.prototype.getAddressFromCoords = function (lat, lng) {
        return this.http.get(this.url + 'geocode=' + lng + "," + lat);
    };
    YamapngService.prototype.getCoordsFromAddress = function (adress) {
        return this.http.get(this.url + 'geocode=' + adress);
    };
    YamapngService.prototype.createSuggest = function (el, opt) {
        this.suggestView = new ymaps.SuggestView(el, opt);
        return this.suggestView;
    };
    YamapngService.prototype.parseAutoComplite = function () {
        var arrStr = this.suggestView.state.get('items');
        arrStr.forEach(function (element) {
            console.log(element);
            element.displayName = element.displayName + '123';
        });
        this.suggestView.state.set('items', arrStr);
    };
    YamapngService.prototype.getSuggests = function (request, opt) {
        return ymaps.suggest(request, opt);
    };
    YamapngService.ngInjectableDef = defineInjectable({ factory: function YamapngService_Factory() { return new YamapngService(inject(LAZY_MAPS_API_CONFIG, 8), inject(HttpClient)); }, token: YamapngService, providedIn: "root" });
    YamapngService = __decorate([
        Injectable({
            providedIn: 'root',
        }),
        __param(0, Optional()), __param(0, Inject(LAZY_MAPS_API_CONFIG)),
        __metadata("design:paramtypes", [Object, HttpClient])
    ], YamapngService);
    return YamapngService;
}());

var YamapngComponent = /** @class */ (function () {
    function YamapngComponent() {
    }
    YamapngComponent.prototype.ngOnInit = function () {
    };
    YamapngComponent = __decorate([
        Component({
            selector: 'lib-yamapng',
            template: "\n    <p>\n      yamapng works!\n    </p>\n  "
        }),
        __metadata("design:paramtypes", [])
    ], YamapngComponent);
    return YamapngComponent;
}());

var YamapngModule = /** @class */ (function () {
    function YamapngModule() {
    }
    YamapngModule = __decorate([
        NgModule({
            declarations: [YamapngComponent],
            imports: [],
            exports: [YamapngComponent]
        })
    ], YamapngModule);
    return YamapngModule;
}());

var YaMapsAPIWrapper = /** @class */ (function () {
    function YaMapsAPIWrapper(_loader, _zone, d) {
        var _this = this;
        this._loader = _loader;
        this._zone = _zone;
        this._documentRef = d;
        this._map = new Promise(function (resolve) {
            _this._mapResolver = resolve;
        });
    }
    YaMapsAPIWrapper.prototype.createMap = function (el, mapOptions) {
        var _this = this;
        var res = this._loader.load().then(function () {
            var create = function () { return setTimeout(function () {
                if (ymaps.Map) {
                    var map = new ymaps.Map(el, mapOptions, {
                        suppressMapOpenBlock: true
                    });
                    _this._mapResolver(map);
                }
                else {
                    create();
                }
            }, 100); };
            create();
        }).catch(function (e) { return console.log(e); });
        return res;
    };
    YaMapsAPIWrapper.prototype.destroyMap = function () {
        this._map.then(function (map) {
            map.destroy();
        });
    };
    YaMapsAPIWrapper.prototype.setCenter = function (latitude, longitude) {
        this._map.then(function (map) {
            map.setCenter([latitude, longitude]);
        });
    };
    YaMapsAPIWrapper.prototype.getCenter = function () {
        return this._map.then(function (map) {
            return map.getCenter();
        });
    };
    YaMapsAPIWrapper.prototype.panTo = function (points, options) {
        this._map.then(function (map) {
            map.panTo(points, options);
        });
    };
    YaMapsAPIWrapper.prototype.subscribeToMapEvent = function (eventName) {
        var _this = this;
        return Observable.create(function (observer) {
            _this._map.then(function (m) {
                m.events.add(eventName, function (arg) { _this._zone.run(function () { return observer.next(arg); }); });
            });
        });
    };
    YaMapsAPIWrapper.prototype.createMarker = function (marker) {
        return this._map.then(function (map) {
            var m = new ymaps.Placemark([marker.latitude, marker.longitude], {
                balloonContentHeader: marker.balloonContentHeader,
                balloonContentBody: marker.balloonContentBody,
                balloonContentFooter: marker.balloonContentFooter,
                iconContent: marker.iconContent
            }, {
                draggable: marker.draggable,
                preset: marker.preset,
                iconLayout: marker.iconLayout,
                iconImageHref: marker.iconImageHref,
                iconImageSize: marker.iconImageSize,
                iconImageOffset: marker.iconImageOffset
            });
            map.geoObjects.add(m);
            return m;
        });
    };
    YaMapsAPIWrapper.prototype.removeGeo = function (overlay) {
        this._map.then(function (map) {
            map.geoObjects.remove(overlay);
        });
    };
    YaMapsAPIWrapper.prototype.createClaster = function (claster) {
        return this._map.then(function (map) {
            if (claster.markers.length === 0) {
                return;
            }
            var myGeoObjects;
            myGeoObjects = new Array();
            claster.markers.forEach(function (x) {
                var point = new ymaps.GeoObject({
                    geometry: { type: x.type, coordinates: [x.lat, x.lng] }
                });
                myGeoObjects.push(point);
            });
            var clusterer = new ymaps.Clusterer({});
            clusterer.add(myGeoObjects);
            map.geoObjects.add(clusterer);
            return clusterer;
        });
    };
    YaMapsAPIWrapper.prototype.createObjectManager = function (objectManager) {
        return this._map.then(function (map) {
            if (objectManager.datasource.length === 0) {
                return;
            }
            var nativeObjectManager = new ymaps.ObjectManager({
                clusterize: objectManager.clusterize,
                gridSize: objectManager.gridSize
            });
            nativeObjectManager.add(objectManager.datasource);
            nativeObjectManager.objects.options.set('preset', objectManager.objectPreset);
            nativeObjectManager.clusters.options.set('preset', objectManager.clasterPreset);
            map.geoObjects.add(nativeObjectManager);
            return nativeObjectManager;
        });
    };
    YaMapsAPIWrapper.prototype.navigateToGeoObject = function (objectManager, id) {
        var obj = objectManager.objects.getById(id);
        if (obj) {
            this.setCenter(obj.geometry.coordinates[0], obj.geometry.coordinates[1]);
            objectManager.objects.balloon.open(id);
        }
    };
    YaMapsAPIWrapper.prototype.checkYaSciptLoaded = function () {
        return this._documentRef.getNativeDocument().getElementById('YaScript');
    };
    YaMapsAPIWrapper.prototype.objectManagerSetFilter = function (objectManager, filter) {
        objectManager.setFilter(filter);
    };
    YaMapsAPIWrapper.prototype.addCrosshair = function () {
        return this._map.then(function (map) {
            var style = map.panes.get('events').getElement().style;
            style.background = 'url("http://t1.rbxcdn.com/03e863d541704e442033d597945ab2e6") no-repeat center';
            style.backgroundSize = '100px';
        });
    };
    YaMapsAPIWrapper = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [YaMapsAPILoader, NgZone, DocumentRef])
    ], YaMapsAPIWrapper);
    return YaMapsAPIWrapper;
}());

var MarkerManager = /** @class */ (function () {
    function MarkerManager(_mapsWrapper, _zone) {
        this._mapsWrapper = _mapsWrapper;
        this._zone = _zone;
        this._markers = new Map();
    }
    MarkerManager.prototype.deleteMarker = function (marker) {
        var _this = this;
        var m = this._markers.get(marker);
        if (m == null) {
            return Promise.resolve();
        }
        // tslint:disable-next-line:no-shadowed-variable
        return m.then(function (m) {
            return _this._zone.run(function () {
                // tslint:disable-next-line:no-shadowed-variable
                _this.getNativeMarker(marker).then(function (m) {
                    _this._mapsWrapper.removeGeo(m);
                    _this._markers.delete(marker);
                });
            });
        });
    };
    MarkerManager.prototype.addMarker = function (marker) {
        var markerPromise = this._mapsWrapper.createMarker(marker);
        this._markers.set(marker, markerPromise);
    };
    MarkerManager.prototype.showBalloon = function (marker) {
        this.getNativeMarker(marker).then(function (m) {
            m.balloon.open();
        });
    };
    MarkerManager.prototype.getNativeMarker = function (marker) {
        return this._markers.get(marker);
    };
    MarkerManager.prototype.createEventObservable = function (eventName, marker) {
        var _this = this;
        return Observable.create(function (observer) {
            _this._markers.get(marker).then(function (m) {
                m.events.add(eventName, function (e) { return _this._zone.run(function () { return observer.next(e); }); });
            });
        });
    };
    MarkerManager = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [YaMapsAPIWrapper, NgZone])
    ], MarkerManager);
    return MarkerManager;
}());

var markerId = 0;
var YaMarker = /** @class */ (function () {
    function YaMarker(_markerManager) {
        this._markerManager = _markerManager;
        this.draggable = false;
        this.preset = 'islands#blueIcon';
        this.markerClick = new EventEmitter();
        // tslint:disable-next-line:max-line-length
        this.dragEnd = new EventEmitter();
        this._markerAddedToManger = false;
        this._observableSubscriptions = [];
        this._id = (markerId++).toString();
    }
    YaMarker.prototype.ngOnChanges = function (changes) {
        if (!this._markerAddedToManger) {
            this._markerManager.addMarker(this);
            this._markerAddedToManger = true;
            this._addEventListeners();
            return;
        }
        if (changes['showInfo']) {
            this._markerManager.showBalloon(this);
        }
        if (changes['latitude'] || changes['longitude']) {
            this._markerManager.getNativeMarker(this).then(function (m) {
                var lt;
                var lg;
                var coords = m.geometry.getCoordinates();
                if (changes['latitude']) {
                    lt = changes['latitude'].currentValue;
                }
                else {
                    lt = coords[0];
                }
                if (changes['longitude']) {
                    lg = changes['longitude'].currentValue;
                }
                else {
                    lg = coords[1];
                }
                m.geometry.setCoordinates([lt, lg]);
            });
        }
    };
    YaMarker.prototype.ngOnDestroy = function () {
        this._markerManager.deleteMarker(this);
        this._observableSubscriptions.forEach(function (s) { return s.unsubscribe(); });
    };
    YaMarker.prototype._addEventListeners = function () {
        var _this = this;
        // click event
        var cs = this._markerManager.createEventObservable('click', this).subscribe(function () {
            _this._markerManager.showBalloon(_this);
            _this.markerClick.emit(null);
        });
        this._observableSubscriptions.push(cs);
        // dragend event
        // tslint:disable-next-line:max-line-length
        var ds = this._markerManager.createEventObservable('dragend', this).subscribe(function (e) {
            var thisPlacemark = e.get('target');
            var coords = thisPlacemark.geometry.getCoordinates();
            _this._markerManager.getNativeMarker(_this).then(function (m) {
                // tslint:disable-next-line:max-line-length
                _this.dragEnd.emit({ lat: coords[0], lng: coords[1], nativeMarker: m });
            });
        });
        this._observableSubscriptions.push(ds);
    };
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], YaMarker.prototype, "latitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], YaMarker.prototype, "longitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "balloonLayout", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], YaMarker.prototype, "balloonContentHeader", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], YaMarker.prototype, "balloonContentBody", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], YaMarker.prototype, "balloonContentFooter", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "draggable", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "preset", void 0);
    __decorate([
        Input(),
        __metadata("design:type", String)
    ], YaMarker.prototype, "iconContent", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], YaMarker.prototype, "showInfo", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "iconLayout", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "iconImageHref", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "iconImageSize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMarker.prototype, "iconImageOffset", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], YaMarker.prototype, "markerClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], YaMarker.prototype, "dragEnd", void 0);
    YaMarker = __decorate([
        Directive({
            // tslint:disable-next-line:directive-selector
            selector: 'ya-marker',
            providers: [
                YaMapsAPIWrapper
            ]
        })
        // tslint:disable-next-line:directive-class-suffix
        ,
        __metadata("design:paramtypes", [MarkerManager])
    ], YaMarker);
    return YaMarker;
}());

var ClasterManager = /** @class */ (function () {
    function ClasterManager(_mapsWrapper, _zone) {
        this._mapsWrapper = _mapsWrapper;
        this._zone = _zone;
        this._clasters = new Map();
    }
    ClasterManager.prototype.addClaster = function (claster) {
        var clasterPromise = this._mapsWrapper.createClaster(claster);
        this._clasters.set(claster, clasterPromise);
    };
    ClasterManager = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [YaMapsAPIWrapper, NgZone])
    ], ClasterManager);
    return ClasterManager;
}());

var clasterId = 0;
var YaClaster = /** @class */ (function () {
    function YaClaster(_clasterManager) {
        this._clasterManager = _clasterManager;
        this._markerAddedToManger = false;
        this._id = (clasterId++).toString();
    }
    YaClaster.prototype.ngOnChanges = function (changes) {
        if (!this._markerAddedToManger) {
            this._clasterManager.addClaster(this);
        }
    };
    YaClaster.prototype.ngOnDestroy = function () { };
    YaClaster.prototype._addEventListeners = function () { };
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], YaClaster.prototype, "markers", void 0);
    YaClaster = __decorate([
        Directive({
            // tslint:disable-next-line:directive-selector
            selector: 'ya-claster',
            providers: [
                YaMapsAPIWrapper
            ]
        })
        // tslint:disable-next-line:directive-class-suffix
        ,
        __metadata("design:paramtypes", [ClasterManager])
    ], YaClaster);
    return YaClaster;
}());

var ObjectManagerManager = /** @class */ (function () {
    function ObjectManagerManager(_mapsWrapper, _zone) {
        this._mapsWrapper = _mapsWrapper;
        this._zone = _zone;
        this._managers = new Map();
    }
    ObjectManagerManager.prototype.add = function (manager) {
        var managerPromise = this._mapsWrapper.createObjectManager(manager);
        this._managers.set(manager, managerPromise);
    };
    ObjectManagerManager.prototype.navigateToGeoObject = function (manager, id) {
        var _this = this;
        this.getNativeManager(manager).then(function (p) {
            _this._mapsWrapper.navigateToGeoObject(p, id);
        });
    };
    ObjectManagerManager.prototype.getNativeManager = function (manager) {
        return this._managers.get(manager);
    };
    ObjectManagerManager.prototype.setFilter = function (manager, filter) {
        var _this = this;
        this.getNativeManager(manager).then(function (p) {
            _this._mapsWrapper.objectManagerSetFilter(p, filter);
        });
    };
    ObjectManagerManager = __decorate([
        Injectable(),
        __metadata("design:paramtypes", [YaMapsAPIWrapper, NgZone])
    ], ObjectManagerManager);
    return ObjectManagerManager;
}());

var markerId$1 = 0;
var YaObjectManager = /** @class */ (function () {
    function YaObjectManager(_manager) {
        this._manager = _manager;
        this.clusterize = false;
        this.clasterPreset = 'islands#blueIcon';
        this.objectPreset = 'islands#blueClusterIcons';
        this.gridSize = 0;
        this._observableSubscriptions = [];
        this._addedToManger = false;
        this._id = (markerId$1++).toString();
    }
    YaObjectManager.prototype.ngOnChanges = function (changes) {
        if (!this._addedToManger) {
            this._manager.add(this);
            this._addedToManger = true;
            return;
        }
        if (changes['selectedObjectId']) {
            this._manager.navigateToGeoObject(this, this.selectedObjectId);
        }
        if (changes['filter']) {
            this._manager.setFilter(this, this.filter);
        }
    };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaObjectManager.prototype, "clusterize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaObjectManager.prototype, "datasource", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaObjectManager.prototype, "clasterPreset", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaObjectManager.prototype, "objectPreset", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaObjectManager.prototype, "gridSize", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], YaObjectManager.prototype, "selectedObjectId", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaObjectManager.prototype, "filter", void 0);
    YaObjectManager = __decorate([
        Directive({
            // tslint:disable-next-line:directive-selector
            selector: 'ya-object-manager',
            providers: [
                YaMapsAPIWrapper
            ]
        })
        // tslint:disable-next-line:directive-class-suffix
        ,
        __metadata("design:paramtypes", [ObjectManagerManager])
    ], YaObjectManager);
    return YaObjectManager;
}());

var yandex;

var YaMap = /** @class */ (function () {
    function YaMap(_elem, _mapsWrapper) {
        this._elem = _elem;
        this._mapsWrapper = _mapsWrapper;
        this.longitude = 0;
        this.latitude = 0;
        this.zoom = 8;
        this.mapType = 'yandex#map';
        this.controls = null;
        // tslint:disable-next-line:max-line-length
        this.mapClick = new EventEmitter();
        this.actionTick = new EventEmitter();
        this.boundschange = new EventEmitter();
        this.mapInit = false;
        this._observableSubscriptions = [];
    }
    YaMap.prototype.ngOnInit = function () {
        console.log('map iit');
        var container = this._elem.nativeElement.querySelector('.map-container-inner');
        this._initMapInstance(container);
        this.mapInit = true;
    };
    YaMap.prototype.ngOnDestroy = function () {
        console.log('map del');
        this._mapsWrapper.destroyMap();
    };
    YaMap.prototype.ngOnChanges = function (changes) {
        if (this.mapInit) {
            this.updatePosition(changes);
            this.panTo(changes);
        }
    };
    YaMap.prototype._initMapInstance = function (el) {
        if (this.controls != null) {
            this._mapsWrapper.createMap(el, {
                center: [this.latitude, this.longitude], zoom: this.zoom, type: this.mapType,
                controls: this.controls
            });
        }
        else {
            this._mapsWrapper.createMap(el, {
                center: [this.latitude, this.longitude], zoom: this.zoom, type: this.mapType
            });
        }
        if (this.crosshair) {
            this._mapsWrapper.addCrosshair();
        }
        this._handleMapMouseEvents();
    };
    YaMap.prototype.updatePosition = function (changes) {
        if (changes['latitude'] == null && changes['longitude'] == null) {
            return;
        }
        this._mapsWrapper.setCenter(this.latitude, this.longitude);
    };
    YaMap.prototype.panTo = function (changes) {
        if (changes['panToObjects'] == null) {
            return;
        }
        this._mapsWrapper.panTo(this.panToObjects.points, this.panToObjects.params);
    };
    YaMap.prototype._handleMapMouseEvents = function () {
        var _this = this;
        var clickEvents = [
            { name: 'click', emitter: this.mapClick }
        ];
        var events = [
            { name: 'actiontick', emitter: this.actionTick }
        ];
        var boundschanges = [
            { name: 'boundschange', emitter: this.boundschange }
        ];
        boundschanges.forEach(function (e) {
            var s = _this._mapsWrapper.subscribeToMapEvent(e.name).subscribe(function (event) {
                _this._mapsWrapper.getCenter().then(function (coords) {
                    var value = { lat: coords[0], lng: coords[1] };
                    e.emitter.emit(value);
                });
            });
            _this._observableSubscriptions.push(s);
        });
        clickEvents.forEach(function (e) {
            var s = _this._mapsWrapper.subscribeToMapEvent(e.name).subscribe(function (event) {
                var coords = event.get('coords');
                var value = { lat: coords[0], lng: coords[1] };
                e.emitter.emit(value);
            });
            _this._observableSubscriptions.push(s);
        });
        events.forEach(function (e) {
            var s = _this._mapsWrapper.subscribeToMapEvent(e.name).subscribe(function (event) {
                _this._mapsWrapper.getCenter().then(function (coords) {
                    _this.latitude = coords[0];
                    _this.longitude = coords[1];
                    var value = { lat: coords[0], lng: coords[1] };
                    e.emitter.emit(value);
                });
            });
            _this._observableSubscriptions.push(s);
        });
    };
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMap.prototype, "longitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMap.prototype, "latitude", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMap.prototype, "zoom", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], YaMap.prototype, "minZoom", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Number)
    ], YaMap.prototype, "maxZoom", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMap.prototype, "mapType", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Array)
    ], YaMap.prototype, "controls", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Object)
    ], YaMap.prototype, "panToObjects", void 0);
    __decorate([
        Input(),
        __metadata("design:type", Boolean)
    ], YaMap.prototype, "crosshair", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], YaMap.prototype, "mapClick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], YaMap.prototype, "actionTick", void 0);
    __decorate([
        Output(),
        __metadata("design:type", EventEmitter)
    ], YaMap.prototype, "boundschange", void 0);
    YaMap = __decorate([
        Component({
            // tslint:disable-next-line:component-selector
            selector: 'ya-map',
            providers: [
                YaMapsAPIWrapper,
                MarkerManager,
                ClasterManager,
                ObjectManagerManager
            ],
            template: "\n    <div class=\"map-container-inner\" id=\"map\">\n      <ng-content></ng-content>\n    </div>\n  "
        })
        // class="map-container-inner" id="map"
        // tslint:disable-next-line:component-class-suffix
        ,
        __metadata("design:paramtypes", [ElementRef, YaMapsAPIWrapper])
    ], YaMap);
    return YaMap;
}());

/**
 * @internal
 */
function coreDirectives() {
    return [
        YaMap,
        YaMarker,
        YaClaster,
        YaObjectManager
    ];
}
/**
 * The angular-ya-maps core module. Contains all Directives/Services/Pipes
 * of the core module. Please use `YaCoreModule.forRoot()` in your app module.
 */
var YaCoreModule = /** @class */ (function () {
    function YaCoreModule() {
    }
    YaCoreModule_1 = YaCoreModule;
    /**
     * Please use this method when you register the module at the root level.
     */
    YaCoreModule.forRoot = function (yaMapsAPILoaderConfig) {
        return {
            ngModule: YaCoreModule_1,
            providers: __spread(BROWSER_GLOBALS_PROVIDERS, [
                { provide: YaMapsAPILoader, useClass: YaMapsAPILoader },
                { provide: LAZY_MAPS_API_CONFIG, useValue: yaMapsAPILoaderConfig }
            ]),
        };
    };
    var YaCoreModule_1;
    YaCoreModule = YaCoreModule_1 = __decorate([
        NgModule({ declarations: coreDirectives(), exports: coreDirectives() })
    ], YaCoreModule);
    return YaCoreModule;
}());
function YaCoreModuleForRoot(yaMapsAPILoaderConfig) {
    return [
        YaCoreModule.forRoot(yaMapsAPILoaderConfig)
    ];
}

/*
 * Public API Surface of yamapng
 */

/**
 * Generated bundle index. Do not edit.
 */

export { YaCoreModule, YaCoreModuleForRoot, YamapngComponent, YamapngModule, YamapngService, coreDirectives, yandex, LAZY_MAPS_API_CONFIG as ɵa, YaMapsAPILoader as ɵb, YaMap as ɵc, YaMapsAPIWrapper as ɵd, WindowRef as ɵe, DocumentRef as ɵf, BROWSER_GLOBALS_PROVIDERS as ɵg, MarkerManager as ɵh, ClasterManager as ɵi, ObjectManagerManager as ɵj, YaMarker as ɵk, YaClaster as ɵl, YaObjectManager as ɵm };
//# sourceMappingURL=ayamap.js.map
